==> autoadress-8.x-1.0.tar.gz: autoadress/src/Element/AutocompleteAddress.php <==
<?php

namespace Drupal\autoadress\Element;

use Drupal\address\Element\Address;
use Drupal\autoadress\Constant\SettingConstants;
use Drupal\Core\Render\Element\FormElement;

/**
 * Class AutocompleteAddress.
 *
 * Provides autocomplete form element for addressfield.
 *
 * @package Drupal\autoadress\Element
 *
 * @FormElement("autoadress")
 */
class AutocompleteAddress extends Address {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    $parentInfo = parent::getInfo();

    $parentInfo['#attached']['library'][] = 'autoadress/autocomplete';
    $parentInfo['#pre_render'][] = [$class, 'placeAlgoliaClass'];
    return $parentInfo;
  }

  /**
   * Adds a class to mark the surrounding div.
   */
  public static function placeAlgoliaClass(array $element) {
    $element['#attributes']['class'][] = 'autocomplete-address';

    $autoadressConfig = \Drupal::config(SettingConstants::AUTOADRESS_SETTINGS);
    $drupalSettings = [
      "allowed_countries" => $element['#available_countries'],
    ];
    $algoliaCredentialConfig = $autoadressConfig->get(SettingConstants::ALGOLIA_CREDENTIALS);
    if ($algoliaCredentialConfig) {
      $algoliaCredentials = \Drupal::service('key.repository')
        ->getKey($algoliaCredentialConfig)
        ->getKeyValue();
      \Drupal::messenger()->addMessage(print_r($algoliaCredentials, TRUE));
      $algoliaCredentialsArray = json_decode($algoliaCredentials, TRUE);
      $drupalSettings["appId"] = $algoliaCredentialsArray["username"];
      $drupalSettings["apiKey"] = $algoliaCredentialsArray["password"];
    }

    $element['#attached']['drupalSettings']['autoadress'] = $drupalSettings;
    return $element;
  }

}

==> autoadress-8.x-1.1.tar.gz: autoadress/src/Element/AutocompleteAddress.php <==
<?php

namespace Drupal\autoadress\Element;


use Drupal\address\Element\Address;
use Drupal\autoadress\Constant\SettingConstants;
use Drupal\Core\Render\Element\FormElement;

/**
 * Class AutocompleteAddress.
 *
 * Provides autocomplete form element for addressfield.
 *
 * @package Drupal\autoadress\Element
 *
 * @FormElement("autoaddress")
 */
class AutocompleteAddress extends Address {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    $parentInfo = parent::getInfo();

    $parentInfo['#attached']['library'][] = 'autoadress/autocomplete';
    $parentInfo['#pre_render'][] = [$class, 'placeAlgoliaClass'];
    return $parentInfo;
  }

  /**
   * Adds a class to mark the surrounding div.
   */
  public static function placeAlgoliaClass(array $element) {
    $element['#attributes']['class'][] = 'autocomplete-address';

    $autoaddressConfig = \Drupal::config(SettingConstants::AUTOADDRESS_SETTINGS);
    $drupalSettings = [
      "allowed_countries" => $element['#available_countries'],
    ];
    $algoliaCredentialConfig = $autoaddressConfig->get(SettingConstants::ALGOLIA_CREDENTIALS);
    if ($algoliaCredentialConfig) {
      $algoliaCredentials = \Drupal::service('key.repository')
        ->getKey($algoliaCredentialConfig)
        ->getKeyValue();
      \Drupal::messenger()->addMessage(print_r($algoliaCredentials, TRUE));
      $algoliaCredentialsArray = json_decode($algoliaCredentials, TRUE);
      $drupalSettings["appId"] = $algoliaCredentialsArray["username"];
      $drupalSettings["apiKey"] = $algoliaCredentialsArray["password"];
    }

    $element['#attached']['drupalSettings']['autoaddress'] = $drupalSettings;
    return $element;
  }

}
